@@ -1,6 +1,6 @@
 package TPath;
 {
-  $TPath::VERSION = '0.004';
+  $TPath::VERSION = '0.005';
 }
 
 # ABSTRACT: general purpose path languages for trees
@@ -17,7 +17,7 @@ TPath - general purpose path languages for trees
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -57,20 +57,8 @@ version 0.004
       @{ $n->{children} };
   }
   
-  sub has_tag {
-      my ( $self, $n, $str ) = @_;
-      $str eq $n->{tag};
-  }
-  
-  sub matches_tag {
-      my ( $self, $n, $rx ) = @_;
-      $n->{tag} =~ $rx;
-  }
-  
-  # implement a useful attribute -- @tag
-  
-  sub tag : Attr {
-      my ( $self, $n, $i, $c ) = @_;
+  sub tag : Attr {                 # also an attribute!
+      my ( $self, $n ) = @_;
       $n->{tag};
   }
   
@@ -152,7 +140,8 @@ Forester objects make use of an index (L<TPath::Index>), which caches informatio
 not cheaply from, the nodes themselves. If no index is explicitly provided it is created, but one
 can gain some efficiency by reusing an index when select paths from a tree.
 
-The paths themselves are compiled into reusable objects that can be applied to multiple trees.
+The paths themselves are compiled into reusable L<TPath::Expression> objects that can be applied 
+to multiple trees.
 
 =head1 ALGORITHM
 
